<?php
namespace Teknisa\CADFIS\Controllers\Import;

use Teknisa\Libs\Util\XLS\FileLoader;

abstract class ImportFile
{
    protected $fileContent;
    protected $content;
    
    /**
     * The template method defines the skeleton of an algorithm.
     */
    final public function importData($row)
    {
        $this->import($row);
        $this->getContent();
        $this->formatContent();
        
        return $this->content;
    }

    /**
     * These operations already have implementations.
     */
    protected function import($row): void
    {
        $file = $row['FILE'];
        $this->fileContent = FileLoader::loadFromBase64($file['content'], $file['name']);
        
        if (!$this->fileContent)
            throw new \Exception("Erro ao importar arquivo.");
    }
    
    /**
     * These operations have to be implemented in subclasses.
     */
    abstract protected function getContent(): void;

    abstract protected function formatContent(): void;
}